/******************************************************************************
  Copyright (c) 1992 Xerox Corporation.  All rights reserved.
  Portions of this code were written by Stephen White, aka ghond.
  Use and copying of this software and preparation of derivative works based
  upon this software are permitted.  Any distribution of this software or
  derivative works must comply with all applicable United States export
  control laws.  This software is made available AS IS, and Xerox Corporation
  makes no warranty about the software, its performance or its conformity to
  any specification.  Any person obtaining a copy of this software is requested
  to send their name and post office or electronic mail address to:
    Pavel Curtis
    Xerox PARC
    3333 Coyote Hill Rd.
    Palo Alto, CA 94304
    Pavel@Xerox.Com
 *****************************************************************************/

#ifndef Unparse_h
#define Unparse_h 1

#include "my-stdio.h"
#include "my-string.h"

#include "bytecodes.h"
#include "config.h"
#include "functions.h"
#include "opcode.h"
#include "parse_cmd.h"
#include "streams.h"
#include "structures.h"

typedef void (*Unparser_Receiver)(void *, const char *);

/* the external functions */

#define MAIN_VECTOR -1 /* if f_index == MAIN_VECTOR, main_vector is used */
extern void 	list_prog(Program *, Unparser_Receiver, void *, 
			  char user_paren, char user_tab, int f_index);
extern unsigned	get_lineno(Program *, unsigned pc, int f_index);

extern const char *error_name(enum error); /* E_NONE -> "E_NONE" */
extern const char *unparse_error(enum error errno); /* E_NONE -> "No error" */

extern const char *unparse_option(int);
extern const char *unparse_prep(int);

struct pptable_entry {
    const char         *name;
    Propid              propno;
    var_type	        type;     /* type of property */
    short               settable; /* by whom: 0 for program, 1 for wizard,
                                              2 for builder, 3 for player */
};

extern struct pptable_entry *match_pseudo_property(const char *, Propid *);

#endif

/* $Log: unparse.h,v $
 * Revision 1.7  1992/10/23  23:03:47  pavel
 * Added copyright notice.
 *
 * Revision 1.6  1992/10/21  03:02:35  pavel
 * Converted to use new automatic configuration system.
 *
 * Revision 1.5  1992/08/31  22:23:46  pjames
 * Changed some `char *'s to `const char *'
 *
 * Revision 1.4  1992/08/21  00:40:15  pavel
 * Renamed include file "parse_command.h" to "parse_cmd.h".
 *
 * Revision 1.3  1992/08/13  23:59:27  pavel
 * Converted to a typedef of `var_type' = `enum var_type'.
 *
 * Revision 1.2  1992/08/10  16:41:25  pjames
 * Changed ip to pc.
 *
 * Revision 1.1  1992/07/20  23:23:12  pavel
 * Initial RCS-controlled version.
 * */
